@@ -10,7 +10,7 @@ import time
 import tempfile
 import json
 
-from aws_pcluster_helpers.utils.logging import setup_logger
+from aws_pcluster_bootstrap_helpers.utils.logging import setup_logger
 
 logger = setup_logger("build-ami")
 
